// quad.pov POV-Ray input file to render an LCD display, receiver, speaker and headphones
// (c) January 2005 Mark Stout

// Changes Made:

// 1.  Put garage door behind camera; noticible in reflections. 
// 2.  Re-created Wood and Aluminum textures
// 3.  Replaced solid top on Lafayette Receiver with vented top. 
// 4.  Tried a dozen techniques for making a "burlap" back-wall without using an image map.
//       settled on a bunch of "scaled spheres", but it's still memory-intensive. 
// 5.  Replaced "motorboard" texture on Klipsch speaker with "black painted fir plywood " texture
// 6.  Completely re-did headphone cord and learned how "sphere sweep" works. 
// 7   Moved headphone wires at earcups up about 3/4", straightened cord for strain-relief
// 8.  New knobs on Receiver.
// 9.  Move and change style of "Lafayette" logo to match prototype (tentatively done)
// 10. Replaced image map of "signal strength" meter with CSG equivelent
// 11. Replaced image map of radio dial with CSG equivelent 
// 12. Replaced aluminum receiver face; put "washers" around pushbuttons and 
//       got rid of washers around headphone jacks. 
// 13. Replaced aluminum texture, created "spun aluminum" texture. 
// 14. Added strain relief's to Headphone cord at the plugs and the ear cups. 
// 15. Replaced burlap texture. Doesn't look as good, but uses Much less time and memory! 
// 16. Replaced burlap texture again. Still fast but much better looking 
// 17. Moved "LR-3000" from gold-on-black to black-on-aluminum, fixed font
// 18. Headphone plugs are only be 1" long; were 2"
// 19. Changed Headphone cord and plugs to "cordsatinc" texture from "glossblackc"
// 20. Got an edge view of "dialblue" parts; made stripe thin, put all parts on same plane, 
//       lined up dots so that they look good from all angles. 
// 21. Added ivory lettering to "Selector" knob
// 22. Replaced game settings screen image map with CSG equivelent
// 23. Finished lettering face of receiver
// 24. Added "Stereo" light 
// 25. Finished radio dial pointer  
// 26. Put pointers on radio knobs
// 27. Replaced lettering on headphones with CSG equivelent
// 28. Created non-branded equivelent models

// global

#declare RAD = on;

global_settings {
  assumed_gamma 2.2
  max_trace_level 25
  #if(RAD) 
    radiosity {
    }
  #end
  }

// includes

  #include "textures.inc"
  #include "lights.inc"
  #include "garage.inc"  
  #include "bench.inc"  

// camera

camera {
  location <33.8, 61.0, 52> 
  right <-5/4, 0, 0>    
  up <0, 1, 0>
  look_at <32.8, 60.0, 22>    
  }

// optron = lights + garage + bench + tools

// sum garage, bench and tools into optron

#declare quad = union {
  object { lights }
  object { garage }
  object { bench }
  }

// Action! (Render quad )

object {
  quad 
  } 
  